import { Marpit, Options, ThemeSetPackOptions } from '@marp-team/marpit';
import type { HLJSApi } from 'highlight.js';
import * as emojiPlugin from './emoji/emoji';
import { type HTMLAllowList } from './html/allowlist';
import * as mathPlugin from './math/math';
import * as scriptPlugin from './script/script';
import * as slugPlugin from './slug/slug';
export interface MarpOptions extends Options {
    emoji?: emojiPlugin.EmojiOptions;
    html?: boolean | HTMLAllowList;
    markdown?: object;
    math?: mathPlugin.MathOptions;
    minifyCSS?: boolean;
    script?: boolean | scriptPlugin.ScriptOptions;
    slug?: slugPlugin.SlugOptions;
}
export declare class Marp extends Marpit {
    readonly options: Required<MarpOptions>;
    private _highlightjs;
    static readonly html: {
        readonly a: {
            readonly href: (value: string) => string;
            readonly name: true;
            readonly rel: true;
            readonly target: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly abbr: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly address: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly article: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly aside: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly audio: {
            readonly autoplay: true;
            readonly controls: true;
            readonly loop: true;
            readonly muted: true;
            readonly preload: true;
            readonly src: (value: string) => string;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly b: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly bdi: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly bdo: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly big: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly blockquote: {
            readonly cite: (value: string) => string;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly br: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly caption: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly center: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly cite: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly code: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly col: {
            readonly align: true;
            readonly valign: true;
            readonly span: true;
            readonly width: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly colgroup: {
            readonly align: true;
            readonly valign: true;
            readonly span: true;
            readonly width: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly dd: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly del: {
            readonly cite: (value: string) => string;
            readonly datetime: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly details: {
            readonly open: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly div: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly dl: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly dt: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly em: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly figcaption: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly figure: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly h1: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly h2: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly h3: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly h4: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly h5: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly h6: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly hr: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly i: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly img: {
            readonly align: true;
            readonly alt: true;
            readonly decoding: true;
            readonly height: true;
            readonly loading: true;
            readonly src: (value: string) => string;
            readonly srcset: (value: string) => string;
            readonly title: true;
            readonly width: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
        };
        readonly ins: {
            readonly cite: (value: string) => string;
            readonly datetime: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly kbd: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly li: {
            readonly type: true;
            readonly value: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly mark: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly nav: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly ol: {
            readonly reversed: true;
            readonly start: true;
            readonly type: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly p: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly picture: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly pre: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly source: {
            readonly height: true;
            readonly media: true;
            readonly sizes: true;
            readonly src: (value: string) => string;
            readonly srcset: (value: string) => string;
            readonly type: true;
            readonly width: true;
        };
        readonly q: {
            readonly cite: (value: string) => string;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly rp: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly rt: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly ruby: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly s: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly section: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly small: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly span: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly sub: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly summary: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly sup: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly strong: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly strike: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly table: {
            readonly width: true;
            readonly border: true;
            readonly align: true;
            readonly valign: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly tbody: {
            readonly align: true;
            readonly valign: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly td: {
            readonly width: true;
            readonly rowspan: true;
            readonly colspan: true;
            readonly align: true;
            readonly valign: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly tfoot: {
            readonly align: true;
            readonly valign: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly th: {
            readonly width: true;
            readonly rowspan: true;
            readonly colspan: true;
            readonly align: true;
            readonly valign: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly thead: {
            readonly align: true;
            readonly valign: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly time: {
            readonly datetime: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly tr: {
            readonly rowspan: true;
            readonly align: true;
            readonly valign: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly u: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly ul: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly video: {
            readonly autoplay: true;
            readonly controls: true;
            readonly loop: true;
            readonly muted: true;
            readonly playsinline: true;
            readonly poster: (value: string) => string;
            readonly preload: true;
            readonly src: (value: string) => string;
            readonly height: true;
            readonly width: true;
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
        readonly wbr: {
            readonly class: true;
            readonly dir: (value: string) => string;
            readonly lang: true;
            readonly title: true;
        };
    };
    constructor(opts?: MarpOptions);
    protected applyMarkdownItPlugins(md: any): void;
    get highlightjs(): HLJSApi;
    highlighter(code: string, lang: string, attrs: string): string;
    protected renderStyle(theme?: string): string;
    protected themeSetPackOptions(): ThemeSetPackOptions;
}
export default Marp;
